package jp.agentec.sinaburocast.action.admin;

import java.io.IOException;

import jp.agentec.sinaburocast.action.AbstractAction;
import jp.agentec.sinaburocast.common.SessionBindingListener;
import jp.agentec.sinaburocast.common.SinaburoConstant;
import jp.agentec.sinaburocast.common.SinaburoConstant.UserType;
import jp.agentec.sinaburocast.common.annotation.OperationHistoryAno;
import jp.agentec.sinaburocast.common.exception.ExpectedException;
import jp.agentec.sinaburocast.common.exception.InvalidUrlException;
import jp.agentec.sinaburocast.common.exception.SystemException;
import jp.agentec.sinaburocast.common.util.PropertyUtil;
import jp.agentec.sinaburocast.common.util.SinaburoViewUtil;
import jp.agentec.sinaburocast.entity.AdminUser;
import jp.agentec.sinaburocast.form.admin.AdminLoginForm;
import jp.agentec.sinaburocast.service.AdminUserService;

import org.apache.log4j.Logger;
import org.h2.util.StringUtils;
import org.seasar.struts.annotation.ActionForm;
import org.seasar.struts.annotation.Execute;

/**
 * ログイン処理
 *
 * @author choi-c
 *
 */
public class LoginAction extends AbstractAction {
	private final Logger logger = Logger.getLogger(getClass());

	@ActionForm
	public AdminLoginForm adminLoginForm;
	
	public  AdminUserService adminUserService;

	public static final int sslMode = PropertyUtil.getInt("sslMode");

	
	/**
	 * 初期表示
	 */
	@Execute(validator = false)
	public String index() {
		return "/admin/login/login.html";
	}

	/**
	 * ログイン押下
	 *
	 * @return
	 * @throws IOException
	 * @throws SystemException
	 * @throws ExpectedException
	 */
	@Execute(validator = true, input = "/admin/login/login.html")
	@OperationHistoryAno(operationTypeId=SinaburoConstant.OperationType.LOGIN,target="管理者ログイン",detail="ログイン",screenId=SinaburoConstant.screenId.SAU0001)
	public String auth() throws IOException, SystemException, ExpectedException {

		renewSession();

		AdminUser adminUserInfo = adminUserService.findByLoginId(adminLoginForm.loginId);

		//ログインロジック実装
		if (adminUserInfo == null ||
				!StringUtils.equals(adminUserInfo.password, adminLoginForm.password)) {
			addError(SinaburoViewUtil.getMessage("errors.E002"));
			return "/admin/login/";
		}

		setAuthenticatedToken(adminUserInfo,UserType.MANAGE);
		
		if (sslMode == 1) {
			return "http://"  + request.getServerName() + request.getContextPath() + "/admin/member/?redirect=true";
		}

//		setCookiePath("/em/admin/");
//		setCookiePath("/em/batch/");
//		setCookiePath("/em/user/enqResultList/");

		return "/admin/member/index.html";
	}

	/**
	 * ログアウト
	 *
	 * @return　ログイン画面
	 * @throws IOException
	 * @throws InvalidUrlException
	 */
	@Execute(validator = false)
	@OperationHistoryAno(operationTypeId=SinaburoConstant.OperationType.LOGOUT,target="管理者ログアウト",detail="ログアウト",screenId=SinaburoConstant.screenId.SAU0001)
	public String logout() throws IOException, InvalidUrlException {
		SessionBindingListener listener = (SessionBindingListener) session.getAttribute(SinaburoConstant.AttrKey.BINDING_LISTENER);
		if (listener != null) { // ログアウト押す前にタイムアウトしていた場合はnullになっている
			listener.setCauseAsLogout();
			session.setAttribute(SinaburoConstant.AttrKey.BINDING_LISTENER, listener);
		}

		redirect("/admin/login/");
		session.invalidate(); // リダイレクト時にはまだセッションが有効である必要がある

		return null;
	}

}