package jp.agentec.sinaburocast.action.admin.enquete;

import java.util.Map;

import javax.annotation.Resource;

import jp.agentec.sinaburocast.action.AbstractAction;
import jp.agentec.sinaburocast.common.SinaburoConstant;
import jp.agentec.sinaburocast.common.annotation.OperationHistoryAno;
import jp.agentec.sinaburocast.common.util.PropertyUtil;
import jp.agentec.sinaburocast.common.util.SinaburoUtil;
import jp.agentec.sinaburocast.form.admin.enquete.EnqueteSearchForm;
import jp.agentec.sinaburocast.service.EnqueteService;

import org.apache.log4j.Logger;
import org.seasar.framework.util.StringUtil;
import org.seasar.struts.annotation.ActionForm;
import org.seasar.struts.annotation.Execute;

/**
 * アンケート検索
 *
 * @author choi-c
 *
 */
public class EnqueteSearchAction extends AbstractAction {
	
	private final Logger logger = Logger.getLogger(getClass());

	@ActionForm
	public EnqueteSearchForm enqueteSearchForm;

	public EnqueteService enqueteService;
	
	
	/**
	 * 初期表示
	 */
	@Execute(validator = false,reset="resetIndex")
	public String index() {
		session.removeAttribute("admin_enquete_enqueteResultForm");
		
		enqueteSearchIndex();
		return "/admin/enquete/enqueteSearch.html";
	}
	
	/**アンケートを検索する。*/
	private void enqueteSearchIndex(){
		enqueteSearchForm.searchPath="enqueteSearchIndexPaging/";
		enqueteSearchForm.serverUrl = PropertyUtil.getString("ENQUETE_SERVER_URL");;
		
		enqueteSearchForm.searchResultList = enqueteService.getEnquete1Month(enqueteSearchForm);
	}
	
	/**アンケートを検索する。*/
	@Execute(validator = false,urlPattern="enqueteSearchIndexPaging/{pageNo}" )
	public String enqueteSearchIndexPaging(){
		enqueteSearchForm.serverUrl = PropertyUtil.getString("ENQUETE_SERVER_URL");
		
		enqueteSearchForm.searchResultList = enqueteService.getEnquete1Month(enqueteSearchForm);
		
		return "/admin/enquete/enqueteSearch.html";
	}
	
	/**
	 * 検索
	 */
	@Execute(validator = false,urlPattern="search/{pageNo}" )
	public String search() {
		enqueteSearchForm.searchPath="search/";
		enqueteSearch();
		return "/admin/enquete/enqueteSearch.html";
	}
	
	/**
	 * Formの日付のチェックを行う。
	 */
	private void formCheck(){
		if(StringUtil.isNotBlank(enqueteSearchForm.operationTermFrom) && !SinaburoUtil.checkDate(enqueteSearchForm.operationTermFrom)){
			addErrorMessage("dateError", "errors.E033");
			addErrorMessage("dateError_1", "errors.E033_1");
			addErrorMessage("dateError_2", "errors.E033_2");
		}else if(StringUtil.isNotBlank(enqueteSearchForm.operationTermTo) && !SinaburoUtil.checkDate(enqueteSearchForm.operationTermTo)){
			addErrorMessage("dateError", "errors.E033");
			addErrorMessage("dateError_1", "errors.E033_1");
			addErrorMessage("dateError_2", "errors.E033_2");
		}else if(StringUtil.isNotBlank(enqueteSearchForm.operationTermFrom) && StringUtil.isNotBlank(enqueteSearchForm.operationTermTo)
				&& enqueteSearchForm.operationTermTo.compareTo(enqueteSearchForm.operationTermFrom) < 0
				){
			addErrorMessage("dateError", "errors.E020");
		}
	}
	
	/**
	 * アンケートを論理削除する。
	 * @return 
	 */
	@Execute(validator = false )
	@OperationHistoryAno(operationTypeId=SinaburoConstant.OperationType.DELETE,target="アンケート削除",detail="アンケート削除",screenId=SinaburoConstant.screenId.CEN0001)
	public String enqueteDelete() {
		int delCount=enqueteService.enqueteDelete(enqueteSearchForm.eid,getAdmin());
		if(delCount<=0){
			request.setAttribute(SinaburoConstant.notRegistOperationHistoryKey.notRegist, SinaburoConstant.notRegistOperationHistoryKey.notRegist);
		}
		
		enqueteSearch();
		return "/admin/enquete/enqueteSearch.html";
	}
	
	@Resource
	protected Map requestScope;
	
	/**アンケートを検索する。*/
	private void enqueteSearch(){
		formCheck();
		if(hasErrors()){
			return;
		}
		enqueteSearchForm.serverUrl = PropertyUtil.getString("ENQUETE_SERVER_URL");
		
		enqueteSearchForm.searchResultList = enqueteService.getEnqueteByNameStartEnd(enqueteSearchForm);
	}
	
	/**
	 * アンケート登録完了画面からの戻り。
	 * 直近1ヶ月を検索する。→検索条件を維持した上で検索を行うように修正。
	 * @return
	 */
	@Execute(validator = false/*,reset="resetIndex"*/)
	public String back() {
//		enqueteSearchForm.operationTermFrom = SinaburoUtil.dateDispFormat(SinaburoUtil.addMonth(-1));
//		enqueteSearchForm.operationTermTo = SinaburoUtil.dateDispFormat(SinaburoUtil.addMonth(0));
		enqueteSearch();
		return "/admin/enquete/enqueteSearch.html";
	}
	

}